@@ -2,7 +2,7 @@ context("Reading and writing NIfTI files")
 
 test_that("NIfTI files can be read and written", {
     imagePath <- system.file("extdata", "example.nii.gz", package="RNifti")
-    tempPath <- tempfile()
+    tempPath <- paste(tempfile(), "nii.gz", sep=".")
     
     expect_that(dim(readNifti(imagePath,internal=FALSE)), equals(c(96L,96L,60L)))
     expect_that(dim(readNifti(imagePath,internal=TRUE)), equals(c(96L,96L,60L)))
@@ -27,4 +27,11 @@ test_that("NIfTI files can be read and written", {
     
     image <- updateNifti(image, list(intent_code=1000L))
     expect_that(dumpNifti(image)$intent_code, equals(1000L))
+    
+    expect_that(image[40,40,30], equals(368))
+    image <- readNifti(imagePath, internal=TRUE)
+    expect_that(as.array(image)[40,40,30], equals(368))
+    image <- RNifti:::rescaleNifti(image, c(0.5,0.5,0.5))
+    expect_that(pixdim(image), equals(c(5,5,5)))
+    expect_that(as.array(image), gives_warning("no data"))
 })
